@@ -7,6 +7,17 @@ from libacr.views.manager import ViewsManager
 from libacr.plugins.manager import PluginsManager
 from libacr.mediaWorker import start_media_worker
 
+import tg
+if tg.version == '2.1':
+    print 'TG2.1 found, helpers work-around in place'
+    import tg.render, pylons
+    def patched_pylons_globals():
+        x = tg.render.my_pylons_globals()
+        if x['h'] == {}:
+            conf = pylons.config._current_obj()
+            x['h'] = conf['package'].lib.helpers
+        return x
+    pylons.templating.pylons_globals = patched_pylons_globals
 
 class Globals(object):
     """Container for objects available throughout the life of the application.
